==> haskell-language-c-0.8.3-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-c.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 language-c
version:              0.8.3
visibility:           public
id:                   language-c-0.8.3-37O7krZaCqAG98hGRoYBvx
key:                  language-c-0.8.3-37O7krZaCqAG98hGRoYBvx
license:              BSD-3-Clause
copyright:            LICENSE
maintainer:           benedikt.huber@gmail.com
author:               AUTHORS
stability:            experimental
homepage:             http://visq.github.io/language-c/
synopsis:             Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of C11 and clang/GNU extensions.

category:             Language
abi:                  e5ef1b246119429683989ebb667477a7
exposed:              True
exposed-modules:
    Language.C Language.C.Analysis Language.C.Analysis.AstAnalysis
    Language.C.Analysis.Builtins Language.C.Analysis.ConstEval
    Language.C.Analysis.Debug Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.DefTable Language.C.Analysis.Export
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.SemError
    Language.C.Analysis.SemRep Language.C.Analysis.TravMonad
    Language.C.Analysis.TypeCheck Language.C.Analysis.TypeConversions
    Language.C.Analysis.TypeUtils Language.C.Data Language.C.Data.Error
    Language.C.Data.Ident Language.C.Data.InputStream
    Language.C.Data.Name Language.C.Data.Node Language.C.Data.Position
    Language.C.Parser Language.C.Pretty Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.System.GCC
    Language.C.System.Preprocess

hidden-modules:
    Language.C.Data.RList Language.C.Parser.Builtin
    Language.C.Parser.Lexer Language.C.Parser.ParserMonad
    Language.C.Parser.Tokens Language.C.Parser.Parser

import-dirs:          /usr/lib/ghc-8.10.4/site-local/language-c-0.8.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/language-c-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/language-c-0.8.3
hs-libraries:         HSlanguage-c-0.8.3-37O7krZaCqAG98hGRoYBvx
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    deepseq-1.4.4.0 directory-1.3.6.0 filepath-1.4.2.1 pretty-1.1.3.6
    process-1.6.9.0 syb-0.7.2.1-7IivvRpEqey3Ddb4vsqX1J

haddock-interfaces:   /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html:         /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-language-c-0.8.3-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-language-c.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 language-c
version:              0.8.3
visibility:           public
id:                   language-c-0.8.3-LWnT0e309vgBb5LTDRbiyh
key:                  language-c-0.8.3-LWnT0e309vgBb5LTDRbiyh
license:              BSD-3-Clause
copyright:            LICENSE
maintainer:           benedikt.huber@gmail.com
author:               AUTHORS
stability:            experimental
homepage:             http://visq.github.io/language-c/
synopsis:             Analysis and generation of C code
description:
    Language C is a haskell library for the analysis and generation of C code.
    It features a complete, well tested parser and pretty printer for all of C99 and a large
    set of C11 and clang/GNU extensions.

category:             Language
abi:                  ec657d16bcfb46ad9a792b6d0278a899
exposed:              True
exposed-modules:
    Language.C Language.C.Analysis Language.C.Analysis.AstAnalysis
    Language.C.Analysis.Builtins Language.C.Analysis.ConstEval
    Language.C.Analysis.Debug Language.C.Analysis.DeclAnalysis
    Language.C.Analysis.DefTable Language.C.Analysis.Export
    Language.C.Analysis.NameSpaceMap Language.C.Analysis.SemError
    Language.C.Analysis.SemRep Language.C.Analysis.TravMonad
    Language.C.Analysis.TypeCheck Language.C.Analysis.TypeConversions
    Language.C.Analysis.TypeUtils Language.C.Data Language.C.Data.Error
    Language.C.Data.Ident Language.C.Data.InputStream
    Language.C.Data.Name Language.C.Data.Node Language.C.Data.Position
    Language.C.Parser Language.C.Pretty Language.C.Syntax
    Language.C.Syntax.AST Language.C.Syntax.Constants
    Language.C.Syntax.Ops Language.C.Syntax.Utils Language.C.System.GCC
    Language.C.System.Preprocess

hidden-modules:
    Language.C.Data.RList Language.C.Parser.Builtin
    Language.C.Parser.Lexer Language.C.Parser.ParserMonad
    Language.C.Parser.Tokens Language.C.Parser.Parser

import-dirs:          /usr/lib/ghc-8.10.4/site-local/language-c-0.8.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/language-c-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/language-c-0.8.3
hs-libraries:         HSlanguage-c-0.8.3-LWnT0e309vgBb5LTDRbiyh
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    deepseq-1.4.4.0 directory-1.3.6.0 filepath-1.4.2.1 pretty-1.1.3.6
    process-1.6.9.0 syb-0.7.2.1-IHzu7I6ikCoGwAbnu6OBXz

haddock-interfaces:   /usr/share/doc/haskell-language-c/html/language-c.haddock
haddock-html:         /usr/share/doc/haskell-language-c/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
